# yaf
Yet Another Forecast. A minimalistic weather forecast library and a cli app.


Weather forecast data from Yr, delivered by the [Norwegian Meteorological Institute and the NRK](http://om.yr.no/verdata/free-weather-data/).


Usage conditions and guidelines:

- [Original version](http://om.yr.no/verdata/)
- [English explanation](http://om.yr.no/verdata/free-weather-data)
